package com.efunbox.reader.application;

import android.app.Application;
import android.content.Context;
import android.os.Environment;


import com.bumptech.glide.Glide;
import com.bumptech.glide.Priority;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.request.RequestOptions;
import com.efunbox.reader.util.Consts;
import com.efunbox.reader.util.HttpInterceptor;
import com.okhttplib.OkHttpUtil;
import com.okhttplib.annotation.CacheType;
import com.okhttplib.annotation.Encoding;
import com.okhttplib.cookie.PersistentCookieJar;
import com.okhttplib.cookie.cache.SetCookieCache;
import com.okhttplib.cookie.persistence.SharedPrefsCookiePersistor;
import com.umeng.commonsdk.UMConfigure;

import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlPullParserFactory;

import java.io.File;

public class EApplication extends Application {
    @Override
    public void onCreate() {
        super.onCreate();
        try {
            Consts.setmApplicAtion(this);
            XmlPullParserFactory.newInstance().setFeature("http://apache.org/xml/features/disallow-doctype-decl", true);
            //初始化OKHTTP
            String downloadFileDir = Environment.getExternalStorageDirectory().getPath() + "/okHttp_download/";
            String cacheDir = Environment.getExternalStorageDirectory().getPath() + "/okHttp_cache";
            OkHttpUtil.init(getApplicationContext())
                    .setConnectTimeout(15)//连接超时时间
                    .setWriteTimeout(15)//写超时时间
                    .setReadTimeout(15)//读超时时间
                    .setMaxCacheSize(10 * 1024 * 1024)//缓存空间大小
                    .setCacheType(CacheType.FORCE_NETWORK)//缓存类型
                    .setHttpLogTAG("HttpLog")//设置请求日志标识
                    .setIsGzip(false)//Gzip压缩，需要服务端支持
                    .setShowHttpLog(true)//显示请求日志
                    .setShowLifecycleLog(false)//显示Activity销毁日志
                    .setRetryOnConnectionFailure(false)//失败后不自动重连
                    .setCachedDir(new File(cacheDir))//设置缓存目录
                    .setDownloadFileDir(downloadFileDir)//文件下载保存目录
                    .setResponseEncoding(Encoding.UTF_8)//设置全局的服务器响应编码
                    .setRequestEncoding(Encoding.UTF_8)//设置全局的请求参数编码
//                    .setHttpsCertificate("12306.cer")//设置全局Https证书
                    .addResultInterceptor(HttpInterceptor.ResultInterceptor)//请求结果拦截器
                    .addExceptionInterceptor(HttpInterceptor.ExceptionInterceptor)//请求链路异常拦截器
                    .setCookieJar(new PersistentCookieJar(new SetCookieCache(), new SharedPrefsCookiePersistor(getApplicationContext())))//持久化cookie
                    .build();


            //初始化友盟
            UMConfigure.init(this, UMConfigure.DEVICE_TYPE_PHONE, "");
        } catch (XmlPullParserException e) {
            e.printStackTrace();
        }


    }
}
