package com.efunbox.reader.base;

import android.app.Activity;
import android.os.Build;
import android.os.Bundle;
import android.view.View;
import android.view.WindowManager;

import com.efunbox.reader.annotation.BindView;
import com.efunbox.reader.util.LiuHaiScreenUtil;

import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import androidx.appcompat.app.ActionBar;
import androidx.appcompat.app.AppCompatActivity;
import io.reactivex.rxjava3.annotations.Nullable;

public abstract class BaseActivity extends AppCompatActivity {


    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(this.getLayoutId());
        getWindow().setFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON, WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.P) {
            LiuHaiScreenUtil.openFullScreenModel(this);
        }
        bindViews(this);
        initView();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
    }

    /**
     * 设置布局
     *
     * @return
     */
    public abstract int getLayoutId();

    /**
     * 初始化视图
     */
    public abstract void initView();


    public static void bindViews(Activity activity) {
        Class<? extends Activity> activityClass = activity.getClass();//获取activity的class
        Field[] fields = activityClass.getDeclaredFields();//获取activity的字段
        //遍历所有的字段
        for (Field field : fields) {
            //获取该字段的注解
            BindView bindView = field.getAnnotation(BindView.class);
            //!=null 说明该字段有注解并且是指定的注解
            if (bindView != null) {
                //获取到注解总传入的数值value
                int viewId = bindView.id();
                if (viewId != -1) {
                    try {
                        //获取到activity中findViewById的方法
                        Method findViewByIdMethod = activityClass.getMethod("findViewById", int.class);
                        try {
                            //执行findViewById方法
                            Object resView = findViewByIdMethod.invoke(activity, viewId);
                            //允许通过反射访问私有变量
                            field.setAccessible(true);
                            //把字段的值设置该view的实例
                            field.set(activity, resView);
                        } catch (IllegalAccessException e) {
                            e.printStackTrace();
                        } catch (InvocationTargetException e) {
                            e.printStackTrace();
                        }
                    } catch (NoSuchMethodException e) {
                        e.printStackTrace();
                    }
                }
            }
        }
    }
}